@@ -62,7 +62,11 @@ public:
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   virtual void do_menu_file_print(); //override
-
+  
+  #ifdef GLOM_ENABLE_MAEMO
+  void do_menu_file_add_record();
+  #endif
+  
   void get_record_counts(gulong& total, gulong& found);
 
   enum dataview
@@ -88,6 +92,14 @@ protected:
 
   virtual void on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageNumber);
 
+private:
+  #ifdef GLOM_ENABLE_MAEMO
+  void on_window_maemo_details_closed();
+  #endif
+
+  bool on_idle_show_details(const Gnome::Gda::Value& primary_key_value);
+
+protected:
   //Member widgets:
   Box_Data_List m_Box_List;
   Box_Data_Details m_Box_Details;
