@@ -23,7 +23,7 @@
 #include <gtkmm/messagedialog.h>
 #include "../dialog_invalid_data.h"
 #include <libglom/data_structure/glomconversions.h>
-#include "../application.h"
+#include <glom/application.h>
 #include <glibmm/i18n.h>
 //#include <sstream> //For stringstream
 
@@ -31,19 +31,13 @@
 #include <ctime>     // for struct tm
 #include <iostream>   // for cout, endl
 
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildon/hildon-touch-selector-entry.h>
+#endif
+
 namespace Glom
 {
 
-ComboEntryGlom::ComboEntryGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& /* refGlade */)
-: Gtk::ComboBoxEntry(cobject)
-{
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  setup_menu();
-#endif // !GLOM_ENABLE_CLIENT_ONLY
-
-  init();
-}
-
 ComboEntryGlom::ComboEntryGlom()
 : ComboGlomChoicesBase()
 {
@@ -64,11 +58,52 @@ ComboEntryGlom::ComboEntryGlom(const sharedptr<LayoutItem_Field>& field_second)
   init();
 }
 
+Gtk::Entry* ComboEntryGlom::get_entry()
+{
+  #ifndef GLOM_ENABLE_MAEMO
+  return Gtk::ComboBoxEntry::get_entry();
+  #else
+  return m_maemo_selector.get_entry();
+  #endif
+}
+
+const Gtk::Entry* ComboEntryGlom::get_entry() const
+{
+  #ifndef GLOM_ENABLE_MAEMO
+  return Gtk::ComboBoxEntry::get_entry();
+  #else
+  return m_maemo_selector.get_entry();
+  #endif
+}
+
 void ComboEntryGlom::init()
 {
+#ifndef GLOM_ENABLE_MAEMO
   set_model(m_refModel);
-
   set_text_column(m_Columns.m_col_first);
+#else
+  //Maemo:
+  set_selector(m_maemo_selector);
+ 
+  //We don't use append_text_column(), because we want to specify no expand.
+  //Glib::RefPtr<Hildon::TouchSelectorColumn> column =
+  //  m_maemo_selector.append_text_column(m_refModel);
+  // Only in the latest hildonmm: Glib::RefPtr<Hildon::TouchSelectorColumn> column =
+  //  m_maemo_selector.append_column(m_refModel);
+  Glib::RefPtr<Hildon::TouchSelectorColumn> column = Glib::wrap(hildon_touch_selector_append_column(
+      HILDON_TOUCH_SELECTOR(m_maemo_selector.gobj()), GTK_TREE_MODEL(Glib::unwrap(m_refModel)), 0, static_cast<char*>(0)), true);
+      
+  column->pack_start(m_Columns.m_col_first, false);
+  //Only in the latest hildonmm: column->set_text_column(m_Columns.m_col_first);
+  column->set_property("text_column", 0);
+  
+  //Only in the latest hildonmm: m_maemo_selector->set_text_column(m_Columns.m_col_first);
+  m_maemo_selector.set_text_column(0);
+
+  
+  //m_maemo_selector.set_model(0, m_refModel);
+  //m_maemo_selector.set_text_column(0);
+#endif
 
   //We use connect(slot, false) to connect before the default signal handler, because the default signal handler prevents _further_ handling.
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -79,11 +114,16 @@ void ComboEntryGlom::init()
   get_entry()->signal_activate().connect(sigc::mem_fun(*this, &ComboEntryGlom::on_entry_activate));
 
 #ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
+  #ifndef GLOM_ENABLE_MAEMO
   signal_changed().connect(sigc::mem_fun(*this, &ComboEntryGlom::on_changed));
+  #else
+  m_maemo_selector.signal_changed().connect(sigc::mem_fun(*this, &ComboEntryGlom::on_changed));
+  #endif
 #endif // GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
 
   if(m_with_second)
   {
+    #ifndef GLOM_ENABLE_MAEMO
     //We don't use this convenience method, because we want more control over the renderer.
     //and CellLayout gives no way to get the renderer back afterwards.
     //(well, maybe set_cell_data_func(), but that's a bit awkward.)
@@ -96,11 +136,14 @@ void ComboEntryGlom::init()
     pack_start(*cell_second);
 
     //Make the renderer render the column:
-#ifdef GLIBMM_PROPERTIES_ENABLED
+    #ifdef GLIBMM_PROPERTIES_ENABLED
     add_attribute(cell_second->_property_renderable(), m_Columns.m_col_second);
-#else
+    #else
     add_attribute(*cell_second, cell_second->_property_renderable(), m_Columns.m_col_second);
-#endif
+    #endif
+    #else //GLOM_ENABLE_MAEMO
+    column->pack_start(m_Columns.m_col_second, false);
+    #endif //GLOM_ENABLE_MAEMO
   }
 }
 
@@ -113,10 +156,19 @@ void ComboEntryGlom::set_layout_item(const sharedptr<LayoutItem>& layout_item, c
   //Call base class:
   ComboGlomChoicesBase::set_layout_item(layout_item, table_name);
 
-  //Right-align numbers:
-  sharedptr<const LayoutItem_Field> layout_field = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
-  if(layout_field && layout_field->get_glom_type() == Field::TYPE_NUMERIC)
-      get_entry()->set_alignment(1.0); //Align numbers to the right.
+  if(!layout_item)
+    return;
+
+  //Horizontal Alignment:
+  FieldFormatting::HorizontalAlignment alignment = 
+    FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT;
+  sharedptr<LayoutItem_Field> layout_field =
+    sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
+  if(layout_field)
+    alignment = layout_field->get_formatting_used_horizontal_alignment();
+
+  const float x_align = (alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT ? 0.0 : 1.0);
+  get_entry()->set_alignment(x_align); 
 }
 
 void ComboEntryGlom::check_for_change()
@@ -197,16 +249,43 @@ void ComboEntryGlom::on_entry_changed()
 
 void ComboEntryGlom::set_value(const Gnome::Gda::Value& value)
 {
-  sharedptr<const LayoutItem_Field> layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
-  if(layout_item)
+  sharedptr<const LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+  if(!layout_item)
+    return;
+
+  set_text(Conversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format));
+
+  //Show a different color if the value is numeric, if that's specified:
+  if(layout_item->get_glom_type() == Field::TYPE_NUMERIC)
   {
-    set_text(Conversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format));
+    Gtk::Entry* entry = get_entry();
+    if(!entry)
+      return;
+
+    const Glib::ustring fg_color = 
+    layout_item->get_formatting_used().get_text_format_color_foreground_to_use(value);
+    if(!fg_color.empty())
+      entry->modify_text(Gtk::STATE_NORMAL, Gdk::Color(fg_color));
+    else
+      entry->modify_text(Gtk::STATE_NORMAL, Gdk::Color());
   }
 }
 
 void ComboEntryGlom::set_text(const Glib::ustring& text)
 {
   m_old_text = text;
+  
+  #if GLOM_ENABLE_MAEMO
+  for(Gtk::TreeModel::iterator iter = m_refModel->children().begin(); iter != m_refModel->children().end(); ++iter)
+  {
+    const Glib::ustring& this_text = (*iter)[m_Columns.m_col_first];
+
+    if(this_text == text)
+    {
+      set_selected(iter);
+    }
+  }
+  #endif //GLOM_ENABLE_MAEMO
 
   //Call base class:
   get_entry()->set_text(text);
@@ -225,7 +304,7 @@ bool ComboEntryGlom::on_entry_button_press_event(GdkEventButton *event)
 {
   //Enable/Disable items.
   //We did this earlier, but get_application is more likely to work now:
-  App_Glom* pApp = get_application();
+  Application* pApp = get_application();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -255,15 +334,19 @@ bool ComboEntryGlom::on_entry_button_press_event(GdkEventButton *event)
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-App_Glom* ComboEntryGlom::get_application()
+Application* ComboEntryGlom::get_application()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
 
-  return dynamic_cast<App_Glom*>(pWindow);
+  return dynamic_cast<Application*>(pWindow);
 }
 
+#ifndef GLOM_ENABLE_MAEMO
 void ComboEntryGlom::on_changed()
+#else
+void ComboEntryGlom::on_changed(int /* column */)
+#endif 
 {
 #ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   //Call base class:
@@ -272,7 +355,12 @@ void ComboEntryGlom::on_changed()
 
   //This signal is emitted for every key press, but sometimes it's just to say that the active item has changed to "no active item",
   //if the text is not in the dropdown list:
+  #ifndef GLOM_ENABLE_MAEMO
   Gtk::TreeModel::iterator iter = get_active();
+  #else
+  Gtk::TreeModel::iterator iter = get_selected();
+  #endif //GLOM_ENABLE_MAEMO
+  
   if(iter)
   {
     //This is either a choice from the dropdown menu, or someone has typed in something that is in the drop-down menu.
