@@ -35,7 +35,7 @@
 namespace Glom
 {
 
-class App_Glom;
+class Application;
 
 /** A Gtk::ComboBoxEntry that can show choices of field values.
  * Use this when the user should be allowed to enter values directly too,
@@ -99,7 +99,7 @@ private:
   virtual bool on_entry_button_press_event(GdkEventButton *event);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual App_Glom* get_application();
+  virtual Application* get_application();
   
   Gtk::Entry* get_entry();
   const Gtk::Entry* get_entry() const;
