@@ -60,12 +60,12 @@ void LabelGlom::init()
   //but we also want to allow changing of the background color, so we don't use it: set_visible_window(false);
 }
 
-App_Glom* LabelGlom::get_application()
+Application* LabelGlom::get_application()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
 
-  return dynamic_cast<App_Glom*>(pWindow);
+  return dynamic_cast<Application*>(pWindow);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -105,7 +105,7 @@ void LabelGlom::on_menu_properties_activate()
 
 bool LabelGlom::on_button_press_event(GdkEventButton *event)
 {
-  App_Glom* pApp = get_application();
+  Application* pApp = get_application();
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
